"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ZSchema = require("z-schema");
// @todo 264263 - utilize the schema validator in sp-build-common
const fs = require("fs");
const os_1 = require("os");
const path = require("path");
// Discover the schema files
const schemasDirectory = path.join(__dirname, 'manifestSchemas', 'jsonSchemas');
const schemaFiles = fs.readdirSync(schemasDirectory);
const schemas = schemaFiles.map((schemaFile) => require(path.join(schemasDirectory, schemaFile)));
const manifestSchema = require('./manifestSchemas/jsonSchemas/client-side-component-manifest.schema.json');
const applicationSchema = require('./manifestSchemas/jsonSchemas/client-side-application-manifest.schema.json');
const webPartSchema = require('./manifestSchemas/jsonSchemas/client-side-web-part-manifest.schema.json');
const commandSetSchema = require('./manifestSchemas/jsonSchemas/command-set-extension-manifest.schema.json');
const extensionSchema = require('./manifestSchemas/jsonSchemas/client-side-extension-manifest.schema.json');
const librarySchema = require('./manifestSchemas/jsonSchemas/client-side-library-manifest.schema.json');
const assemblySchema = require('./manifestSchemas/jsonSchemas/client-side-assembly-manifest.schema.json');
const multiVersionSchema = require('./manifestSchemas/jsonSchemas/client-side-multi-version-manifest.schema.json');
exports.zSchemaOptions = {
    breakOnFirstError: true,
    forceAdditional: true,
    forceItems: true,
    forceMaxLength: false,
    forceProperties: false,
    noExtraKeywords: true,
    noTypeless: true,
    noEmptyStrings: true
};
const schemaValidator = new exports.ZSchema(exports.zSchemaOptions);
schemaValidator.validateSchema(schemas);
class ManifestValidator {
    static validateApplicationManifest(manifest) {
        return ManifestValidator._validateManifest(manifest, applicationSchema);
    }
    static validateCommandSetManifest(manifest) {
        return ManifestValidator._validateManifest(manifest, commandSetSchema);
    }
    static validateExtensionManifest(manifest) {
        return ManifestValidator._validateManifest(manifest, extensionSchema);
    }
    static validateWebPartManifest(manifest // tslint:disable-line:no-any
    ) {
        return ManifestValidator._validateManifest(manifest, webPartSchema);
    }
    static validateLibraryManifest(manifest) {
        return ManifestValidator._validateManifest(manifest, librarySchema);
    }
    static validateAssemblyManifest(manifest) {
        return ManifestValidator._validateManifest(manifest, assemblySchema);
    }
    static validateMultiVersionManifest(manifest // tslint:disable-line:no-any
    ) {
        return ManifestValidator._validateManifest(manifest, multiVersionSchema);
    }
    static validateManifest(manifest) {
        return ManifestValidator._validateManifest(manifest, manifestSchema);
    }
    static extractInnerErrorMessages(errors) {
        const printZSchemaError = (error) => {
            let innerErrors = [];
            (error.inner || []).forEach((innerErr) => {
                innerErrors = innerErrors.concat(printZSchemaError(innerErr));
            });
            return [`(${error.path}) ${error.message}`].concat(innerErrors);
        };
        let errorList = [];
        errors.map((error) => { errorList = errorList.concat(printZSchemaError(error)); });
        return errorList;
    }
    static getFormattedErrorMessage(errors) {
        return this.extractInnerErrorMessages(errors).join(os_1.EOL);
    }
    static _validateManifest(
        // tslint:disable-next-line:no-any
        manifest, schema) {
        if (!schema) {
            throw new Error('Unable to find the manifest schema.');
        }
        if (typeof manifest === 'string') {
            manifest = JSON.parse(manifest);
        }
        const result = schemaValidator.validate(manifest, schema);
        return {
            result: result,
            errors: schemaValidator.getLastErrors() || []
        };
    }
}
exports.default = ManifestValidator;
//# sourceMappingURL=manifestSchemaValidator.js.map